@@ -1,4 +1,4 @@
-// ------------------------------------------------------------------------------------------------|
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 //     Copyright (C) 2018  Reza Mohammadi                                                          |
 //                                                                                                 |
 //     This file is part of ssgraph package.                                                       |
@@ -8,19 +8,19 @@
 //     Software Foundation; see <https://cran.r-project.org/web/licenses/GPL-3>.                   |
 //                                                                                                 |
 //     Maintainer: Reza Mohammadi <a.mohammadi@uva.nl>                                             |
-// ------------------------------------------------------------------------------------------------|
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 
 #include "matrix.h"
 #include "copula.h"
 
 extern "C" {
-// ------------------------------------------------------------------------------------------------|
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 // MCMC sampling algorithm for Gaussian copula graphical models using spike-and-slab priors  
 // it is for Bayesian model averaging (MA)
-// ------------------------------------------------------------------------------------------------|
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void gcgm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[], int *p, 
             double K_hat[], double p_links[], int *n,
-            double Z[], int R[], int is_discrete[], int *gcgm, 
+            double Z[], int R[], int not_continuous[], int *gcgm, 
             double *v1, double *v2, double *lambda, double g_prior[], int *print )
 {
     double var_1    = *v1;
@@ -67,7 +67,7 @@ void gcgm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[]
 
         //----- STEP 1: copula --------------------------------------------------------------------|		
         
-        get_S( K, Z, R, is_discrete, S, gcgm, n, &dim );
+        get_S( K, Z, R, not_continuous, S, gcgm, n, &dim );
         
         //----- STEP 2: updating graph G and precision matrix K, row by row -----------------------|		
        
@@ -187,15 +187,15 @@ void gcgm_spike_slab_ma( int *iter, int *burnin, int G[], double K[], double S[]
     //-- End of main loop for MCMC algorithm ----------------------------------------------------------| 
 }
     
-// ------------------------------------------------------------------------------------------------|
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 // MCMC sampling algorithm for Gaussian copula graphical models using spike-and-slab priors  
 // it is for maximum a posterior probability estimation (MAP)
-// ------------------------------------------------------------------------------------------------|
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 void gcgm_spike_slab_map( int *iter, int *burnin, int G[], double K[], double S[], int *p, 
                          double K_hat[], double p_links[], int *n,
                          int all_graphs[], double all_weights[], 
                          char *sample_graphs[], double graph_weights[], int *size_sample_g,
-                         double Z[], int R[], int is_discrete[], int *gcgm, 
+                         double Z[], int R[], int not_continuous[], int *gcgm, 
                          double *v1, double *v2, double *lambda, double g_prior[], int *print )
 {
     double var_1    = *v1;
@@ -249,7 +249,7 @@ void gcgm_spike_slab_map( int *iter, int *burnin, int G[], double K[], double S[
         
         //----- STEP 1: copula --------------------------------------------------------------------|		
         
-        get_S( K, Z, R, is_discrete, S, gcgm, n, &dim );
+        get_S( K, Z, R, not_continuous, S, gcgm, n, &dim );
         
         //----- STEP 2: updating graph G and precision matrix K, row by row -----------------------|		
              
